[TOC]

## AT+POWER 发射功率

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+POWER=?          | +POWER:(`<power>`列表)<br><br>OK |
| 设置命令 | AT+POWER=`<power>` | OK                               |
| 查询命令 | AT+POWER?           | +POWER:`<power>`<br><br>OK       |

**参数**

------------
`<power>`：整型。发射功率[10,7,5,0,-10,-15,-20,-30]。

------------

**举例**
```shell
AT+POWER=?

+POWER:[10,7,5,0,-10,-15,-20,-30]

OK

AT+POWER?

+POWER:10

OK

AT+POWER=10

OK

```

## AT+ARATE 空中速率

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+ARATE=?          | +ARATE:(`<rate>`范围)<br><br>OK |
| 设置命令 | AT+ARATE=`<rate>` | OK                               |
| 查询命令 | AT+ARATE?           | +ARATE:`<rate>`<br><br>OK       |

**参数**

------------
`<rate>`：整型。空中速率（300-250000000），相同速率的节点，才能正常通信。

------------

**举例**
```shell
AT+ARATE=?

+ARATE:(300,250000000)

OK

AT+ARATE?

+ARATE:1200

OK

AT+ARATE=1500

OK

```

## AT+CHAN 射频信道数

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+CHAN=?          | +CHAN:(`<channr>`范围)<br><br>OK |
| 设置命令 | AT+CHAN=`<channr>` | OK                               |
| 查询命令 | AT+CHAN?           | +CHAN:`<channr>`<br><br>OK       |

**参数**

------------
`<channr>`：整型。8 位无符号信道数（0-255），被信道间隔设置相乘，再加到基频率上。

------------

**举例**
```shell
AT+CHAN=?

+CHAN:(0,255)

OK

AT+CHAN?

+CHAN:2

OK

AT+CHAN=3

OK

```

## AT+ADDR 设备地址

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+ADDR=?          | +ADDR:(`<address>`范围)<br><br>OK |
| 设置命令 | AT+ADDR=`<address>` | OK                               |
| 查询命令 | AT+ADDR?           | +ADDR:`<address>`<br><br>OK       |

**参数**

------------
`<address>`：整型。数据包过滤时使用的地址。可选广播地址为 0（0x00）和 255（0xFF）。

------------

**举例**
```shell
AT+ADDR=?

+ADDR:(0,255)

OK

AT+ADDR?

+ADDR:2

OK

AT+ADDR=3

OK

```

## AT+RADDR AT命令响应回传地址

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+RADDR=?          | +ADDR:(`<address>`范围)<br><br>OK |
| 设置命令 | AT+RADDR=`<address>` | OK                               |
| 查询命令 | AT+RADDR?           | +ADDR:`<address>`<br><br>OK       |

**参数**

------------
`<address>`：整型。执行远程AT命令时，响应回传到该地址。范围为非广播地址。

------------

**举例**
```shell
AT+RADDR=?

+RADDR:(1,254)

OK

AT+RADDR?

+RADDR:2

OK

AT+RADDR=3

OK

```

## AT+SEND 向远程节点发送数据

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+SEND=?          | OK |
| 设置命令 | AT+SEND=`<message>,<address>[,<channr>]` | +SEND:`[<channr>,]<address>,<message>`<br><br>OK                               |


**参数**

------------
`<message>`：字符串。消息内容。
`<address>`：整型。远程节点的设备地址。
`<channr>`：整型。远程节点的信道数。

------------

**备注**

------------
向远程节点发送AT命令，命令需按以下规则转义。

| 原字符 | 转义后字符 |
| ------ | ---------- |
| `<CR>` | *          |
| `<LF>` | *          |
|   ,     |    ;        |
|    "    |     '       |
|    ?    |       $     |


------------
**举例**
```shell
#向信道1，地址1的节点发送消息
AT+SEND="Hello",1,1

+SEND:1,1,hello

OK
#地址1节点，收到URC报告
+WD:[hello]
#向信道1，地址1的节点发送AT命令,设置该节点后续执行远程AT命令时的响应回传地址。
AT+SEND="AT+RADDR=3**",1,1

+SEND:1,1,at+raddr=3**

OK

+WD:[
OK
]
#地址1节点，收到包含AT命令的URC报告
+WD:[at+raddr=3**]
OK

#向地址1节点发送数据采集命令,指定回传地址为本节点地址3
at+send="at+colt=3**",1,1

+SEND:1,1,at+colt=3**

OK

+WD:[+data:DI(0,0,0,0),AI(0,0,0,0),EXTRA($GPRMC,,V,,,,,,,,,,N*53]
+WD:[
)

OK
]
```