[TOC]


## AT+POWO 关机

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+POWO=?          | +POWO:(`<POWO>`列表)<br><br>OK |
| 设置命令 | AT+POWO=`<POWO>` | OK                               |
| 执行命令 | AT+POWO           | POWER-OFF<br><br>OK       |

**参数**

------------
`<POWO>`：整型。关机选型，0：立即关机，1：正常关机。

------------

**举例**
```shell
AT+POWO=?

+POWO:[0,1]

OK

AT+POWO

POWER-OFF

OK

AT+POWO=0

OK

```

## AT+IPR 串口通信波特率

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+IPR=?          | +IPR:(`<rate>`列表)<br><br>OK |
| 设置命令 | AT+IPR=`<rate>` | OK                               |
| 查询命令 | AT+IPR?           | +IPR:`<rate>`<br><br>OK       |

**参数**

------------
`<rate>`：整型。串口通信波特率支持2400、4800、9600、14400、19200、28800、33600、38400、57600、115200。

------------

**举例**
```shell
AT+IPR=?

+IPR:[2400,4800,9600,14400,19200,28800,33600,38400,57600,115200]

OK

AT+IPR?

+IPR:9600

OK

AT+IPR=9600

OK

```

## AT+ENABLE 外设电源使能

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+ENABLE=?          | OK |
| 设置命令 | AT+ENABLE=`<device_name>,<enable>` | +ENABLE:`<device_name>,<enable>`<br><br>OK                               |


**参数**

------------
`<device_name>`：字符串。外设名称。
`<enable>`：整型。外设使能值，0：关闭，1：打开。

------------

**备注**

------------
外设列表：

| 外设名称 | 定义        |
| -------- | ----------- |
| uart1    | 串口1       |
| uart2    | 串口2       |
| uart3    | 串口3       |
| gps      | 串口gps模块 |
| led1     | led灯，编号为1 |
| led2     | led灯，编号为2 |
| led3     | led灯，编号为3 |

------------
**举例**
```shell
#打开串口1电源
AT+ENABLE="uart1",1

+ENABLE:uart1,1

OK
#打开GPS模块电源
AT+ENABLE="gps",1

+ENABLE:gps,1

OK
```

## AT+DO 数字量输出

| 命令类型 | 命令格式           | 响应                             |
| -------- | ------------------ | -------------------------------- |
| 测试命令 | AT+DO=?          | OK |
| 设置命令 | AT+DO=`<gpio_index>,<gpio_val>` | +DO:`<gpio_index>,<gpio_val>`<br><br>OK                               |


**参数**

------------
`<gpio_index>`：整型。数字量通道编号。
`<gpio_val>`：整型。外设使能值，0：关闭，1：打开。

------------

**备注**

------------
数字量输出通道列表：

| 通道编号 | 定义        |
| -------- | ----------- |
| 1    | 数字量输出通道1       |
| 2    | 数字量输出通道2       |
| 3    | 数字量输出通道3       |
| 4      | 数字量输出通道4 |

------------
**举例**
```shell
#设置数字量输出通道1高电平
AT+DO=1,1

+DO:1,1

OK
#设置数字量输出通道2低电平
AT+DO=2,0

+DO:2,0

OK
```

## AT+DI 数字量输入

| 命令类型 | 命令格式             | 响应                                    |
| -------- | -------------------- | --------------------------------------- |
| 测试命令 | AT+DI=?              | OK                                      |
| 设置命令 | AT+DI=`<di_index>` | +DI:`<di_index>,<di_val>`<br><br>OK |
| 查询命令         |   AT+DI?                   | +DI:(`<di1_val>`,`<di2_val>`,`<di3_val>`,`<di4_val>`)<br><br>OK                                        |


**参数**

------------
`<di_index>`：整型。数字量输入通道编号。
`<di_val>`：整型。数字量输入通道电平，0：低电平，1：高电平。
`<di1_val>`：整型。数字量输入通道1电平。
`<di2_val>`：整型。数字量输入通道2电平。
`<di3_val>`：整型。数字量输入通道3电平。
`<di4_val>`：整型。数字量输入通道4电平。

------------

**备注**

------------
数字量输出通道列表：

| 通道编号 | 定义        |
| -------- | ----------- |
| 1    | 数字量输入通道1       |
| 2    | 数字量输入通道2       |
| 3    | 数字量输入通道3       |
| 4      | 数字量输入通道4 |

------------
**举例**
```shell
#采集数字量输入通道1电平
AT+DI=1

+DI:1,1

OK
#采集数字量输入通道2电平
AT+DI=2

+DI:2,0

OK
#采集全部数字量输入通道电平
AT+DI?

+DI:(0,0,0,0)

OK
```
## AT+AI 模拟量输入

| 命令类型 | 命令格式             | 响应                                    |
| -------- | -------------------- | --------------------------------------- |
| 测试命令 | AT+AI=?              | OK                                      |
| 设置命令 | AT+AI=`<ai_index>` | +AI:`<ai_index>,<ai_val>`<br><br>OK |
| 查询命令         |   AT+AI?                   | +AI:(`<ai1_val>`,`<ai2_val>`,`<ai3_val>`,`<ai4_val>`)<br><br>OK                                        |


**参数**

------------
`<ai_index>`：整型。模拟量输入通道编号。
`<ai_val>`：浮点型。模拟量输入通道电压值,单位：V。
`<ai1_val>`：浮点型。模拟量输入通道1电压值。
`<ai2_val>`：浮点型。模拟量输入通道2电压值。
`<ai3_val>`：浮点型。模拟量输入通道3电压值。
`<ai4_val>`：浮点型。模拟量输入通道4电压值。

------------

**备注**

------------
模拟量输出通道列表：

| 通道编号 | 定义        |
| -------- | ----------- |
| 1    | 模拟量输入通道1       |
| 2    | 模拟量输入通道2       |
| 3    | 模拟量输入通道3       |
| 4      | 模拟量输入通道4 |

------------
**举例**
```shell
#采集模拟量输入通道1电压
AT+AI=1

+AI:1,3.29

OK
#采集模拟量输入通道2电压
AT+AI=2

+AI:2,0

OK
#采集全部模拟量输入通道电压
AT+AI?

+AI:(3.29,0,0,0)

OK
```

## AT+VBAT 电池电压

| 命令类型 | 命令格式             | 响应                                    |
| -------- | -------------------- | --------------------------------------- |
| 测试命令 | AT+VBAT=?              | OK                                      |
| 查询命令         |   AT+VBAT?                   | +VBAT:`<vbat_val>`<br><br>OK                                        |


**参数**

------------
`<vbat_val>`：浮点型。电池电压值,单位：V。

------------

**举例**
```shell
#采集模拟量输入通道1电压
AT+VBAT?

+VBAT:3.29

OK
```